@@ -1,7 +1,7 @@
 /*
  * qmath - declarations for extended precision rational arithmetic
  *
- * Copyright (C) 1999-2007,2014  David I. Bell
+ * Copyright (C) 1999-2007,2014,2021  David I. Bell
  *
  * Calc is open software; you can redistribute it and/or modify it under
  * the terms of the version 2.1 of the GNU Lesser General Public License
@@ -35,7 +35,7 @@
 #endif
 
 
-#define INITCONSTCOUNT 9    /* number of initnumbs[] pre-defined constants */
+#define INITCONSTCOUNT 12    /* number of initnumbs[] pre-defined constants */
 
 /*
  * Rational arithmetic definitions.
@@ -213,6 +213,8 @@ E_FUNC NUMBER *qacsch(NUMBER *q, NUMBER *epsilon);
 E_FUNC NUMBER *qacoth(NUMBER *q, NUMBER *epsilon);
 E_FUNC NUMBER *qlegtoleg(NUMBER *q, NUMBER *epsilon, BOOL wantneg);
 E_FUNC NUMBER *qpi(NUMBER *epsilon);
+E_FUNC NUMBER *qpidiv180(NUMBER *epsilon);
+E_FUNC NUMBER *qpidiv200(NUMBER *epsilon);
 E_FUNC NUMBER *qcatalan(NUMBER *);
 E_FUNC NUMBER *qbern(ZVALUE z);
 E_FUNC void qfreebern(void);
@@ -273,6 +275,7 @@ static inline NUMBER* qlink(NUMBER* q) { if(q) { (q)->links++; } return q; }
  */
 EXTERN NUMBER _qzero_, _qone_, _qnegone_, _qonehalf_, _qneghalf_, _qonesqbase_;
 EXTERN NUMBER _qtwo_, _qthree_, _qfour_, _qten_;
+EXTERN NUMBER _qtendivnine_, _qninedivten_;
 EXTERN NUMBER * initnumbs[];
 
 
